@@ -118,8 +118,10 @@ def install(ctx: click.Context, force: bool, name: str):
 				commons.returnToMainMenu(ctx)
 				return
 
+		commons.waitAnimation()
 		sshCmd('sudo systemctl stop ProjectAlice')
 		sshCmd('sudo rm -rf ~/ProjectAlice')
+		commons.stopAnimation()
 
 	releaseType = inquirer.select(
 		message='What releases do you want to receive? If you are unsure, leave this to Stable releases!',
@@ -132,7 +134,6 @@ def install(ctx: click.Context, force: bool, name: str):
 		]
 	).execute()
 
-	commons.waitAnimation()
 	confFile = Path(Path.home(), f'.pacli/{name}.yaml')
 	confFile.parent.mkdir(parents=True, exist_ok=True)
 
@@ -156,13 +157,14 @@ def install(ctx: click.Context, force: bool, name: str):
 			commons.printError(f'Failed reading {name}.yaml {e}')
 			commons.returnToMainMenu(ctx, pause=True)
 
-	if name == 'ProjecAlice':
+	if name == 'ProjectAlice':
 		config = getAliceConfig(config, releaseType)
 	elif name == 'ProjectAliceSatellite':
 		config = getAliceSatConfig(config, releaseType)
 	else:
 		commons.printError(f'Unknown install type {name}')
 
+	commons.waitAnimation()
 	with confFile.open(mode='w') as f:
 		yaml.dump(config, f)
 
@@ -423,7 +425,7 @@ def prepareSdCard(ctx: click.Context):  # NOSONAR
 					click.pause()
 				else:
 					break
-	print(drives)
+
 	if len(drives) == 0:
 		commons.printError(f'For some reason I cannot find the SD boot partition mount point {drive}.')
 		commons.returnToMainMenu(ctx, pause=True, message="I'm really sorry, but I just can't continue without this info, sorry for wasting your time...")
@@ -551,9 +553,9 @@ def getAliceConfig(confs, releaseType):
 			validate=EmptyInputValidator(commons.NO_EMPTY)
 	).execute()
 
-	mqttPort = inquirer.number(
+	mqttPort = inquirer.text(
 			message='Mqtt port',
-			default=1883,
+			default='1883',
 			validate=EmptyInputValidator(commons.NO_EMPTY)
 	).execute()
 
@@ -610,8 +612,8 @@ def getAliceConfig(confs, releaseType):
 				default='coqui',
 				choices=[
 					Choice('coqui', name='Coqui'),
-					Choice('snips', name='Snips (English only!)'),
-					Choice('google', name='Google (Online!)'),
+					Choice('snips', name='Snips (/!\ English only)'),
+					Choice('google', name='Google (/!\ Online)'),
 					Choice('deepspeech', name='Deepspeech'),
 					Choice('pocketsphinx', name='PocketSphinx')
 				]
@@ -621,14 +623,15 @@ def getAliceConfig(confs, releaseType):
 				message='Select the TTS engine you want to use',
 				default='pico',
 				choices=[
-					Choice('pico', name='Coqui'),
-					Choice('mycroft', name='Mycroft'),
-					Choice('amazon', name='Amazon'),
-					Choice('google', name='Google'),
-					Choice('watson', name='Watson')
+					Choice('pico', name='Pico (Supports EN, DE, FR, IT only)'),
+					Choice('mycroft', name='Mycroft (Supports EN only)'),
+					Choice('amazon', name='Amazon (/!\ Online) (Supports all languages)'),
+					Choice('google', name='Google (/!\ Online) (Supports all languagese'),
+					Choice('watson', name='Watson (/!\ Online) (Supports EN, DE, FR, IT, PT')
 				]
 		).execute()
 
+		ttsGender = 'male'
 		if tts == 'amazon':
 			awsAccessKey = inquirer.secret(
 					message='Enter your AWS access key',
@@ -642,10 +645,44 @@ def getAliceConfig(confs, releaseType):
 					transformer=lambda _: commons.HIDDEN
 			).execute()
 
+			ttsVoice = inquirer.select(
+				message='Choose your TTS voice',
+				choices=commons.AMAZON_VOICES[activeLanguage] if activeLanguage in commons.AMAZON_VOICES and len(commons.AMAZON_VOICES[activeLanguage]) > 0 else ['en-US']
+			).execute()
+
+			ttsVoice, ttsGender = ttsVoice.split('/')
+
+		elif tts == 'google':
+			ttsVoice = inquirer.select(
+				message='Choose your TTS voice',
+				choices=commons.GOOGLE_VOICES[activeLanguage] if activeLanguage in commons.GOOGLE_VOICES and len(commons.GOOGLE_VOICES[activeLanguage]) > 0 else ['en-US']
+			).execute()
+
+			ttsVoice, ttsGender = ttsVoice.split('/')
+		elif tts == 'watson':
+			ttsVoice = inquirer.select(
+				message='Choose your TTS voice',
+				choices=commons.WATSON_VOICES[activeLanguage] if activeLanguage in commons.WATSON_VOICES and len(commons.WATSON_VOICES[activeLanguage]) > 0 else ['en-US']
+			).execute()
+
+			ttsVoice, ttsGender = ttsVoice.split('/')
+		elif tts == 'mycroft':
+			ttsVoice = inquirer.select(
+				message='Choose your TTS voice',
+				choices=commons.MYCROFT_VOICES[activeLanguage] if activeLanguage in commons.MYCROFT_VOICES and len(commons.MYCROFT_VOICES[activeLanguage]) > 0 else ['en-US']
+			).execute()
+		elif tts == 'pico':
+			ttsVoice = inquirer.select(
+				message='Choose your TTS voice',
+				choices=commons.PICO_VOICES[activeLanguage] if activeLanguage in commons.PICO_VOICES and len(commons.PICO_VOICES[activeLanguage]) > 0 else ['en-US']
+			).execute()
+		else:
+			ttsVoice = 'en-US'
+
 		if tts == 'google' or asr == 'google':
 			googleServiceFile = inquirer.filepath(
 					message='Enter your Google service file path',
-					default='~/',
+					default='',
 					validate=PathValidator(is_file=True, message='Input is not a file')
 			).execute()
 
@@ -689,14 +726,17 @@ def getAliceConfig(confs, releaseType):
 	confs['useHLC'] = installHLC
 	confs['aliceUpdateChannel'] = releaseType
 	confs['skillsUpdateChannel'] = releaseType
+	confs['ttsVoice'] = ttsVoice
+	confs['ttsType'] = ttsGender
 	confs['ttsLanguage'] = f'{activeLanguage}-{activeCountryCode}'
 
 	if soundInstalled:
 		confs['installSound'] = False
 	else:
 		confs['installSound'] = True
-		if audioDevice:
-			confs['audioHardware'][audioDevice] = True
+
+	if audioDevice:
+		confs['audioHardware'][audioDevice] = True
 
 	confs['asr'] = asr
 	confs['awsAccessKey'] = awsAccessKey
@@ -741,8 +781,9 @@ def getAliceSatConfig(confs, releaseType):
 		confs['installSound'] = False
 	else:
 		confs['installSound'] = True
-		if audioDevice:
-			confs['audioHardware'][audioDevice] = True
+
+	if audioDevice:
+		confs['audioHardware'][audioDevice] = True
 
 	return confs
 
